Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2405)

Unified Diff: remoting/test/test_chromoting_client.h

Issue 1237093004: Support for connecting to localhost on the chromoting test driver. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Made changes to comments and variable name. Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/test/test_chromoting_client.h
diff --git a/remoting/test/test_chromoting_client.h b/remoting/test/test_chromoting_client.h
index 03c942f7bb822ee5639bc27e0c0f3ff8ee52eaa4..7e0ddfe2bdeb7f5ed473d0270fa97250712c4c11 100644
--- a/remoting/test/test_chromoting_client.h
+++ b/remoting/test/test_chromoting_client.h
@@ -27,10 +27,12 @@ namespace protocol {
class ClipboardStub;
class HostStub;
class InputStub;
-}
+} // namespace protocol
namespace test {
+struct ConnectionSetupInfo;
+
// Manages a chromoting connection to a remote host. Destroying a
// TestChromotingClient object with an active connection will close it.
// Must be used from a thread running an IO message loop.
@@ -45,10 +47,8 @@ class TestChromotingClient : public ClientUserInterface,
explicit TestChromotingClient(scoped_ptr<VideoRenderer> video_renderer);
~TestChromotingClient() override;
- // Starts a chromoting connection with the specified remote host.
- void StartConnection(const std::string& user_name,
- const std::string& access_token,
- const RemoteHostInfo& remote_host_info);
+ // Starts a Chromoting connection using the specified connection setup info.
+ void StartConnection(const ConnectionSetupInfo& connection_setup_info);
// Ends the current remote connection and updates the connection state.
void EndConnection();

Powered by Google App Engine
This is Rietveld 408576698